import { BaseApi, BaseApiOptions, BasePolling, PollMethod } from './base-api';
import { BasicInformationResponse, P1MeterDataResponse, TelegramResponse } from './types';
import { ParsedTelegram } from './utils/telegram';
export interface P1MeterPolling<TTelegramResponse extends TelegramResponse> extends BasePolling<P1MeterDataResponse> {
    getTelegram: PollMethod<TTelegramResponse>;
}
export declare class P1MeterApi extends BaseApi {
    getBasicInformation<T extends BasicInformationResponse>(): Promise<T>;
    getData<T extends P1MeterDataResponse>(): Promise<T>;
    startPolling(method: 'getData', apiMethod: <T extends P1MeterDataResponse>() => Promise<T>): Promise<void>;
    startPolling(method: 'getTelegram', apiMethod: <T extends TelegramResponse>() => Promise<T>): Promise<void>;
    constructor(baseUrl: string, options?: BaseApiOptions);
    protected get endpoints(): {
        telegram: string;
        basic: string;
        data: string;
    };
    /**
     * Start polling your P1 Meter using a specific method.
     *
     * To start polling, call the `start()` method on the returned object.
     * The polling can be stopped by calling the `stop()` method.
     *
     * Supported methods: `getData`, `getTelegram`
     */
    get polling(): P1MeterPolling<TelegramResponse>;
    /**
     * The /api/v1/telegram endpoint returns the most recent, valid telegram that was given by the P1 meter,
     * therefore this endpoint is only available for the HWE-P1.
     *
     * The telegram validated with its CRC, but not parsed in any form.
     *
     * Note that this endpoint returns plain text instead of formatted JSON, even when an error occours (see Error handling)
     *
     * @link: https://homewizard-energy-api.readthedocs.io/endpoints.html#p1-telegram-api-v1-telegram
     */
    getTelegram<T extends TelegramResponse>(): Promise<T>;
    /**
     * The /api/v1/telegram endpoint returns the most recent, valid telegram that was given by the P1 meter in a text format.
     *
     * This method fetches the telegram and parses it and returns it as a JSON object.
     */
    getParsedTelegram<T extends ParsedTelegram>(): Promise<T>;
}
//# sourceMappingURL=p1-meter-api.d.ts.map